@@ -12,5 +12,7 @@ def setup_periodic_tasks(sender, **kwargs):
 
 
 @app.task(bind=True, name="osism.tasks.ceph.run")
-def run(self, playbook, arguments):
-    return run_ansible_in_environment(self.request.id, "ceph", playbook, arguments)
+def run(self, environment, playbook, arguments, publish=True):
+    return run_ansible_in_environment(
+        self.request.id, "ceph-ansible", environment, playbook, arguments, publish
+    )
